==> openGion6.4.0.3_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF60S.sql <==
/****************************************************************************/
/* GF60 ( ｵﾌﾞｼﾞｪｸﾄﾏｽﾀ定義 )                                                 */
/*                                                                          */
/* Created : 2015/11/16 16:20:03                                            */
/****************************************************************************/
CREATE TABLE GF60 (
   ID       VARCHAR2 (  30 )                    NOT NULL            /*  10 ID           */
 , IDTYPE   VARCHAR2 (  20 )                    NOT NULL            /*  20 IDﾀｲﾌﾟ       */
 , SEQ      NUMBER   (   7 )        DEFAULT 0   NOT NULL            /*  30 順           */
 , FORM     VARCHAR2 (  20 )                    NOT NULL            /*  40 FORM         */
 , NAME_JA  VARCHAR2 ( 200 )                                        /*  50 名称         */
 , DEF1     VARCHAR2 ( 100 )                                        /*  60 項目定義1    */
 , DEF2     VARCHAR2 ( 100 )                                        /*  70 項目定義2    */
 , DEF3     VARCHAR2 ( 100 )                                        /*  80 項目定義3    */
 , DEF4     VARCHAR2 ( 100 )                                        /*  90 項目定義4    */
 , DEF5     VARCHAR2 ( 100 )                                        /* 100 項目定義5    */
 , DEF6     VARCHAR2 ( 100 )                                        /* 110 項目定義6    */
 , ROLES    VARCHAR2 ( 500 )                                        /* 120 ﾛｰﾙｽﾞ        */
 , DYKAN    VARCHAR2 (   8 )                                        /* 130 完成日       */
 , URL      VARCHAR2 ( 200 )                                        /* 140 URL          */
 , CDKATU   VARCHAR2 (   1 )                                        /* 150 活動CD       */
 , UNIQ     NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ      VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET    VARCHAR2 (  14 )                                        /* 820 登録日時     */
 , PGSET    VARCHAR2 (  10 )                                        /* 830 作成PG       */
 , PGPSET   VARCHAR2 (  10 )                                        /* 840 作成親PG     */
 , USRSET   VARCHAR2 (  10 )                                        /* 850 作成社員     */
 , DYUPD    VARCHAR2 (  14 )                                        /* 860 更新日時     */
 , PGUPD    VARCHAR2 (  10 )                                        /* 870 更新PG       */
 , PGPUPD   VARCHAR2 (  10 )                                        /* 880 更新親PG     */
 , USRUPD   VARCHAR2 (  10 )                                        /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K );

CREATE SEQUENCE GF60S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF60T00 
  BEFORE INSERT ON GF60
  FOR EACH ROW 
  BEGIN 
    SELECT GF60S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion6.4.2.0_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF60S.sql <==
/****************************************************************************/
/* GF60 ( ｵﾌﾞｼﾞｪｸﾄﾏｽﾀ定義 )                                                 */
/*                                                                          */
/* Created : 2016/01/07 17:07:19                                            */
/****************************************************************************/
CREATE TABLE GF60 (
   ID       VARCHAR2 (  30 )                    NOT NULL            /*  10 ID           */
 , IDTYPE   VARCHAR2 (  20 )                    NOT NULL            /*  20 IDﾀｲﾌﾟ       */
 , SEQ      NUMBER   (   7 )        DEFAULT 0   NOT NULL            /*  30 順           */
 , FORM     VARCHAR2 (  20 )                    NOT NULL            /*  40 FORM         */
 , NAME_JA  VARCHAR2 ( 200 )                                        /*  50 名称         */
 , DEF1     VARCHAR2 ( 100 )                                        /*  60 項目定義1    */
 , DEF2     VARCHAR2 ( 100 )                                        /*  70 項目定義2    */
 , DEF3     VARCHAR2 ( 100 )                                        /*  80 項目定義3    */
 , DEF4     VARCHAR2 ( 100 )                                        /*  90 項目定義4    */
 , DEF5     VARCHAR2 ( 100 )                                        /* 100 項目定義5    */
 , DEF6     VARCHAR2 ( 100 )                                        /* 110 項目定義6    */
 , ROLES    VARCHAR2 ( 500 )                                        /* 120 ﾛｰﾙｽﾞ        */
 , DYKAN    VARCHAR2 (   8 )                                        /* 130 完成日       */
 , URL      VARCHAR2 ( 200 )                                        /* 140 URL          */
 , CDKATU   VARCHAR2 (   1 )                                        /* 150 活動CD       */
 , UNIQ     NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ      VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET    VARCHAR2 (  14 )                                        /* 820 登録日時     */
 , PGSET    VARCHAR2 (  10 )                                        /* 830 作成PG       */
 , PGPSET   VARCHAR2 (  10 )                                        /* 840 作成親PG     */
 , USRSET   VARCHAR2 (  10 )                                        /* 850 作成社員     */
 , DYUPD    VARCHAR2 (  14 )                                        /* 860 更新日時     */
 , PGUPD    VARCHAR2 (  10 )                                        /* 870 更新PG       */
 , PGPUPD   VARCHAR2 (  10 )                                        /* 880 更新親PG     */
 , USRUPD   VARCHAR2 (  10 )                                        /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );

CREATE SEQUENCE GF60S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF60T00 
  BEFORE INSERT ON GF60
  FOR EACH ROW 
  BEGIN 
    SELECT GF60S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
